==> polymer_elements-0.0.12.tar.gz: tool/generate_docs.sh <==
#!/bin/bash
LIB=polymer_ui_elements
LIB=$LIB,polymer_ui_elements.polymer_ui_accordion
LIB=$LIB,polymer_ui_elements.polymer_ui_animated_pages
LIB=$LIB,polymer_ui_elements.polymer_ui_arrow
LIB=$LIB,polymer_ui_elements.polymer_ui_breadcrumbs
LIB=$LIB,polymer_ui_elements.polymer_ui_card
LIB=$LIB,polymer_ui_elements.polymer_ui_collapsible
LIB=$LIB,polymer_ui_elements.polymer_ui_field
LIB=$LIB,polymer_ui_elements.polymer_ui_icon
LIB=$LIB,polymer_ui_elements.polymer_ui_icon_button
LIB=$LIB,polymer_ui_elements.polymer_ui_menu
LIB=$LIB,polymer_ui_elements.polymer_ui_menu_button
LIB=$LIB,polymer_ui_elements.polymer_ui_menu_item
LIB=$LIB,polymer_ui_elements.polymer_ui_nav_arrow
LIB=$LIB,polymer_ui_elements.polymer_ui_overlay
LIB=$LIB,polymer_ui_elements.polymer_ui_pages
LIB=$LIB,polymer_ui_elements.polymer_ui_rating
LIB=$LIB,polymer_ui_elements.polymer_ui_scaffold
LIB=$LIB,polymer_ui_elements.polymer_ui_sidebar
LIB=$LIB,polymer_ui_elements.polymer_ui_sidebar_header
LIB=$LIB,polymer_ui_elements.polymer_ui_sidebar_menu
LIB=$LIB,polymer_ui_elements.polymer_ui_splitter
LIB=$LIB,polymer_ui_elements.polymer_ui_submenu_item
LIB=$LIB,polymer_ui_elements.polymer_ui_tabs
LIB=$LIB,polymer_ui_elements.polymer_ui_theme_aware
LIB=$LIB,polymer_ui_elements.polymer_ui_toggle_button
LIB=$LIB,polymer_ui_elements.polymer_ui_toolbar

LIB=$LIB,polymer_elements
LIB=$LIB,polymer_elements.polymer_ajax,polymer_elements.polymer_xhr
LIB=$LIB,polymer_elements.polymer_anchor_point
LIB=$LIB,polymer_elements.polymer_animation
LIB=$LIB,polymer_elements.polymer_collapse,polymer_elements.polymer_collapse_toggle
LIB=$LIB,polymer_elements.polymer_cookie
LIB=$LIB,polymer_elements.polymer_file
LIB=$LIB,polymer_elements.polymer_flex_layout,polymer_elements.polymer_flex_panel
LIB=$LIB,polymer_elements.polymer_google_jsapi
LIB=$LIB,polymer_elements.polymer_grid_layout
LIB=$LIB,polymer_elements.polymer_jsonp
LIB=$LIB,polymer_elements.polymer_key_helper
LIB=$LIB,polymer_elements.polymer_layout
LIB=$LIB,polymer_elements.polymer_localstorage
LIB=$LIB,polymer_elements.polymer_media_query
LIB=$LIB,polymer_elements.polymer_meta
LIB=$LIB,polymer_elements.polymer_mock_data
LIB=$LIB,polymer_elements.polymer_overlay,,polymer_elements.polymer_overlay_scale
LIB=$LIB,polymer_elements.polymer_page
LIB=$LIB,polymer_elements.polymer_scrub
LIB=$LIB,polymer_elements.polymer_selection
LIB=$LIB,polymer_elements.polymer_selector
LIB=$LIB,polymer_elements.polymer_shared_lib
LIB=$LIB,polymer_elements.polymer_signals
LIB=$LIB,polymer_elements.polymer_view_source_link

dartdoc --package-root=packages/ --out=../polymer_elements_ghpages/docs --include-lib=$LIB lib/polymer_elements.dart ../polymer_ui_elements/lib/polymer_ui_elements.dart
#

==> polymer_elements-0.3.0.tar.gz: tool/generate_docs.sh <==
#!/bin/bash
LIB=polymer_ui_elements
LIB=$LIB,polymer_ui_elements.polymer_ui_accordion
LIB=$LIB,polymer_ui_elements.polymer_ui_animated_pages
LIB=$LIB,polymer_ui_elements.polymer_ui_arrow
LIB=$LIB,polymer_ui_elements.polymer_ui_breadcrumbs
LIB=$LIB,polymer_ui_elements.polymer_ui_card
LIB=$LIB,polymer_ui_elements.polymer_ui_collapsible
LIB=$LIB,polymer_ui_elements.polymer_ui_field
LIB=$LIB,polymer_ui_elements.polymer_ui_icon
LIB=$LIB,polymer_ui_elements.polymer_ui_icon_button
LIB=$LIB,polymer_ui_elements.polymer_ui_menu
LIB=$LIB,polymer_ui_elements.polymer_ui_menu_button
LIB=$LIB,polymer_ui_elements.polymer_ui_menu_item
LIB=$LIB,polymer_ui_elements.polymer_ui_nav_arrow
LIB=$LIB,polymer_ui_elements.polymer_ui_overlay
LIB=$LIB,polymer_ui_elements.polymer_ui_pages
LIB=$LIB,polymer_ui_elements.polymer_ui_ratings
LIB=$LIB,polymer_ui_elements.polymer_ui_scaffold,polymer_ui_elements.polymer_ui_scaffold2,polymer_ui_elements.polymer_ui_scaffold3 
LIB=$LIB,polymer_ui_elements.polymer_ui_sidebar
LIB=$LIB,polymer_ui_elements.polymer_ui_sidebar_header
LIB=$LIB,polymer_ui_elements.polymer_ui_sidebar_menu
LIB=$LIB,polymer_ui_elements.polymer_ui_splitter
LIB=$LIB,polymer_ui_elements.polymer_ui_submenu_item
LIB=$LIB,polymer_ui_elements.polymer_ui_tabs
LIB=$LIB,polymer_ui_elements.polymer_ui_theme_aware
LIB=$LIB,polymer_ui_elements.polymer_ui_theme_aware.polymer_ui
LIB=$LIB,polymer_ui_elements.polymer_ui_toggle_button
LIB=$LIB,polymer_ui_elements.polymer_ui_toolbar

LIB=$LIB,polymer_elements
LIB=$LIB,polymer_elements.polymer_ajax,polymer_elements.polymer_xhr
LIB=$LIB,polymer_elements.polymer_anchor_point
LIB=$LIB,polymer_elements.polymer_animation
LIB=$LIB,polymer_elements.polymer_collapse,polymer_elements.polymer_collapse_toggle
LIB=$LIB,polymer_elements.polymer_cookie
LIB=$LIB,polymer_elements.polymer_file
LIB=$LIB,polymer_elements.polymer_flex_layout,polymer_elements.polymer_flex_panel
LIB=$LIB,polymer_elements.polymer_google_jsapi
LIB=$LIB,polymer_elements.polymer_grid_layout,
LIB=$LIB,polymer_elements.polymer_jsonp
LIB=$LIB,polymer_elements.polymer_key_helper
LIB=$LIB,polymer_elements.polymer_layout,polymer_elements.polymer_slide
LIB=$LIB,polymer_elements.polymer_localstorage
LIB=$LIB,polymer_elements.polymer_media_query
LIB=$LIB,polymer_elements.polymer_meta
LIB=$LIB,polymer_elements.polymer_mock_data
LIB=$LIB,polymer_elements.polymer_overlay,,polymer_elements.polymer_overlay_scale
LIB=$LIB,polymer_elements.polymer_page
LIB=$LIB,polymer_elements.polymer_scrub
LIB=$LIB,polymer_elements.polymer_selection
LIB=$LIB,polymer_elements.polymer_selector
LIB=$LIB,polymer_elements.polymer_shared_lib
LIB=$LIB,polymer_elements.polymer_signals
LIB=$LIB,polymer_elements.polymer_view_source_link

dartdoc --package-root=packages/ --out=../polymer_elements_ghpages/docs --include-lib=$LIB lib/polymer_elements.dart ../polymer_ui_elements/lib/polymer_ui_elements.dart
#
